<?php

namespace Assetdocs\Store\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Store\Interfaces\StoreRepositoryInterface;

class StoreController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Store\Interfaces\StoreRepositoryInterface $store
     *
     * @return type
     */
    public function __construct(StoreRepositoryInterface $store)
    {
        $this->middleware('web');
        $this->setupTheme(config('theme.themes.public.theme'), config('theme.themes.public.layout'));

        $this->repository = $store;
        parent::__construct();
    }

    /**
     * Show store's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $stores = $this->repository
            ->pushCriteria(new \Assetdocs\Store\Repositories\Criteria\StorePublicCriteria())
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        return $this->theme->of('store::public.store.index', compact('stores'))->render();
    }

    /**
     * Show store.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $store = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->theme->of('store::public.store.show', compact('store'))->render();
    }
}
