<?php

namespace Assetdocs\Store\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Store\Interfaces\SubstoreRepositoryInterface;
use Assetdocs\Store\Repositories\Presenter\SubstoreItemTransformer;

/**
 * Pubic API controller class.
 */
class SubstoreApiController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Substore\Interfaces\SubstoreRepositoryInterface $substore
     *
     * @return type
     */
    public function __construct(SubstoreRepositoryInterface $substore)
    {
        $this->middleware('api');

        $this->repository = $substore;
        parent::__construct();
    }

    /**
     * Show substore's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $substores = $this->repository
            ->pushCriteria(new \Assetdocs\Store\Repositories\Criteria\SubstorePublicCriteria())
            ->setPresenter('\\Assetdocs\\Store\\Repositories\\Presenter\\SubstoreListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $substores['code'] = 2000;
        return response()->json($substores)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show substore.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $substore = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($substore)) {
            $substore         = $this->itemPresenter($module, new SubstoreItemTransformer);
            $substore['code'] = 2001;
            return response()->json($substore)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
