<?php

namespace Assetdocs\Store\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Store\Interfaces\SubstoreRepositoryInterface;

class SubstoreController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Substore\Interfaces\SubstoreRepositoryInterface $substore
     *
     * @return type
     */
    public function __construct(SubstoreRepositoryInterface $substore)
    {
        $this->middleware('web');
        $this->setupTheme(config('theme.themes.public.theme'), config('theme.themes.public.layout'));

        $this->repository = $substore;
        parent::__construct();
    }

    /**
     * Show substore's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $substores = $this->repository
            ->pushCriteria(new \Assetdocs\Store\Repositories\Criteria\SubstorePublicCriteria())
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        return $this->theme->of('store::public.substore.index', compact('substores'))->render();
    }

    /**
     * Show substore.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $substore = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->theme->of('store::public.substore.show', compact('substore'))->render();
    }
}
