<?php

namespace Assetdocs\Store\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Assetdocs\Store\Models\Substore;

class SubstorePolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the substore.
     *
     * @param User $user
     * @param Substore $substore
     *
     * @return bool
     */
    public function view(User $user, Substore $substore)
    {
        if ($user->canDo('store.substore.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $substore->user_id;
    }

    /**
     * Determine if the given user can create a substore.
     *
     * @param User $user
     * @param Substore $substore
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('store.substore.create');
    }

    /**
     * Determine if the given user can update the given substore.
     *
     * @param User $user
     * @param Substore $substore
     *
     * @return bool
     */
    public function update(User $user, Substore $substore)
    {
        if ($user->canDo('store.substore.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $substore->user_id;
    }

    /**
     * Determine if the given user can delete the given substore.
     *
     * @param User $user
     * @param Substore $substore
     *
     * @return bool
     */
    public function destroy(User $user, Substore $substore)
    {
        if ($user->canDo('store.substore.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $substore->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
